# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/torchserve_client',
                'doc_host': 'https://Ankur-singh.github.io',
                'git_url': 'https://github.com/Ankur-singh/torchserve_client',
                'lib_path': 'torchserve_client'},
  'syms': { 'torchserve_client.grpc': { 'torchserve_client.grpc.BaseClient': ('grpc.html#baseclient', 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient.__init__': ( 'grpc.html#baseclient.__init__',
                                                                                        'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient.__repr__': ( 'grpc.html#baseclient.__repr__',
                                                                                        'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient._filter_none_values': ( 'grpc.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient': ( 'grpc.html#inferenceclient',
                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.__init__': ( 'grpc.html#inferenceclient.__init__',
                                                                                             'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.ping': ( 'grpc.html#inferenceclient.ping',
                                                                                         'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.predictions': ( 'grpc.html#inferenceclient.predictions',
                                                                                                'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.stream_predictions': ( 'grpc.html#inferenceclient.stream_predictions',
                                                                                                       'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient': ( 'grpc.html#managementclient',
                                                                                     'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.__init__': ( 'grpc.html#managementclient.__init__',
                                                                                              'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.describe_model': ( 'grpc.html#managementclient.describe_model',
                                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.list_models': ( 'grpc.html#managementclient.list_models',
                                                                                                 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.register_model': ( 'grpc.html#managementclient.register_model',
                                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.scale_worker': ( 'grpc.html#managementclient.scale_worker',
                                                                                                  'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.set_default': ( 'grpc.html#managementclient.set_default',
                                                                                                 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.unregister_model': ( 'grpc.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC': ( 'grpc.html#torchserveclientgrpc',
                                                                                         'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC.__init__': ( 'grpc.html#torchserveclientgrpc.__init__',
                                                                                                  'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC.__repr__': ( 'grpc.html#torchserveclientgrpc.__repr__',
                                                                                                  'torchserve_client/grpc.py')},
            'torchserve_client.proto.inference_pb2': {},
            'torchserve_client.proto.inference_pb2_grpc': {},
            'torchserve_client.proto.management_pb2': {},
            'torchserve_client.proto.management_pb2_grpc': {},
            'torchserve_client.rest': { 'torchserve_client.rest.BaseClient': ('rest.html#baseclient', 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient.__init__': ( 'rest.html#baseclient.__init__',
                                                                                        'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient.__repr__': ( 'rest.html#baseclient.__repr__',
                                                                                        'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient._filter_none_values': ( 'rest.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient._make_request': ( 'rest.html#baseclient._make_request',
                                                                                             'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient': ( 'rest.html#inferenceclient',
                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.__init__': ( 'rest.html#inferenceclient.__init__',
                                                                                             'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.api_description': ( 'rest.html#inferenceclient.api_description',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.explaination': ( 'rest.html#inferenceclient.explaination',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.health_check': ( 'rest.html#inferenceclient.health_check',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.prediction': ( 'rest.html#inferenceclient.prediction',
                                                                                               'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient': ( 'rest.html#managementclient',
                                                                                     'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.__init__': ( 'rest.html#managementclient.__init__',
                                                                                              'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.api_description': ( 'rest.html#managementclient.api_description',
                                                                                                     'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.describe_model': ( 'rest.html#managementclient.describe_model',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.list_models': ( 'rest.html#managementclient.list_models',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.register_model': ( 'rest.html#managementclient.register_model',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.scale_workers': ( 'rest.html#managementclient.scale_workers',
                                                                                                   'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.set_default_version': ( 'rest.html#managementclient.set_default_version',
                                                                                                         'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.unregister_model': ( 'rest.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST': ( 'rest.html#torchserveclientrest',
                                                                                         'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST.__init__': ( 'rest.html#torchserveclientrest.__init__',
                                                                                                  'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST.__repr__': ( 'rest.html#torchserveclientrest.__repr__',
                                                                                                  'torchserve_client/rest.py')}}}
