__version__ = "0.0.2"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_init.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00_init.ipynb 2
from .rest import TorchServeClientREST
from .grpc import TorchServeClientGRPC
